.. _contributing:

Contributing
============

The sisl code is open-source, and thus we encourage external users to contribute
back to the code base.

Any size of contribution is extremely welcome!

- If you've ideas of missing features
- If you've ideas for improving documentation
- If you've found a bug
- If you've found a documentation error
- If you've created a tutorial

Then please share them `here <issue_>`_.
It is recommended to test the development, please follow `these instructions <installation-testing>`_.

Contributing additional test files should be contributed `here <sisl-files>`_.


Contribute external code
------------------------

External toolbox codes may be contributed `here <issue_>`_, then press
"Issue" and select *Contribute toolbox*.

There are two cases of external contributions:

1. If the code is directly integratable into sisl it will be merged into the sisl source.

2. If the code is showing how to use sisl to calculate some physical quantity but is not a general
   implementation, it will be placed in toolbox directory.

Either way, any contribution is very welcome.
